// java wrapper for vtkImageFFT object
//

package vtk;
import vtk.*;

public class vtkImageFFT extends vtkImageFourierFilter
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  public vtkImageFFT() { super(); }

  public vtkImageFFT(long id) { super(id); }
  public native long   VTKInit();

}
